@@ -18,7 +18,7 @@ matchit <- function(formula, data, method = "nearest", distance = "logit",
   ## 7/13/06: Convert character variables to factors as necessary
   ischar <- rep(0, dim(data)[2])
   for (i in 1:dim(data)[2]) 
-	if(is.character(data[,i])) data[,i] <- as.factor(data[,i])
+    if(is.character(data[,i])) data[,i] <- as.factor(data[,i])
   
   ## check inputs
   if (!is.numeric(distance)) {
@@ -26,12 +26,21 @@ matchit <- function(formula, data, method = "nearest", distance = "logit",
     if (!exists(fn1))
       stop(distance, "not supported.")
   }
+  if (is.numeric(distance)) {
+    fn1 <- "distance2user"
+  }
   fn2 <- paste("matchit2", method, sep = "")
   if (!exists(fn2))
     stop(method, "not supported.")
 
   ## obtain T and X
-  tt <- terms(formula)
+  tryerror <- try(model.frame(formula), TRUE)
+  if (distance %in% c("GAMlogit", "GAMprobit", "GAMcloglog", "GAMlog", "GAMcauchit")) {
+    library(mgcv)
+    tt <- terms(mgcv::interpret.gam(formula)$fake.formula)
+  } else {
+    tt <- terms(formula)
+  }
   attr(tt, "intercept") <- 0
   mf <- model.frame(tt, data)
   treat <- model.response(mf)
@@ -63,9 +72,21 @@ matchit <- function(formula, data, method = "nearest", distance = "logit",
     distance <- out1$distance
   }
 
+  ## full mahalanobis matching
+  if(fn1=="distance2mahalanobis"){
+    is.full.mahalanobis <- TRUE
+  } else {is.full.mahalanobis <- FALSE}
+
   ## matching!
-  out2 <- do.call(fn2, list(treat, X, data, distance=distance, discarded, ...)) 
-  
+  out2 <- do.call(fn2, list(treat, X, data, distance=distance, discarded,
+                            is.full.mahalanobis=is.full.mahalanobis, ...)) 
+
+  ## no distance for full mahalanobis matching
+  if(fn1=="distance2mahalanobis"){
+    distance[1:length(distance)] <- NA
+    class(out2) <- c("matchit.mahalanobis","matchit")
+  } 
+
   ## putting all the results together
   out2$call <- mcall
   out2$model <- out1$model
@@ -76,6 +97,16 @@ matchit <- function(formula, data, method = "nearest", distance = "logit",
   }
   out2$distance <- distance
   out2$discarded <- discarded
+
+  ## basic summary
+  nn <- matrix(0, ncol=2, nrow=4)
+  nn[1,] <- c(sum(out2$treat==0), sum(out2$treat==1))
+  nn[2,] <- c(sum(out2$treat==0 & out2$weights>0), sum(out2$treat==1 & out2$weights>0))
+  nn[3,] <- c(sum(out2$treat==0 & out2$weights==0 & out2$discarded==0), sum(out2$treat==1 & out2$weights==0 & out2$discarded==0))
+  nn[4,] <- c(sum(out2$treat==0 & out2$weights==0 & out2$discarded==1), sum(out2$treat==1 & out2$weights==0 & out2$discarded==1))
+  dimnames(nn) <- list(c("All","Matched","Unmatched","Discarded"),
+                       c("Control","Treated"))
+  out2$nn <- nn
   
   return(out2)
 }
